==> ui-list-10.15.2.tgz: package/es/InlineList/__new-tests__/InlineList.test.js <==
var _InlineList, _InlineList2, _InlineList3, _InlineList4, _InlineList5;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import React from 'react';
import '@testing-library/jest-dom';
import { render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import { InlineList } from '../index';
import { runAxeCheck } from '@instructure/ui-axe-check';
describe('<InlineList />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render list items and filter out null/falsy children', async () => {
    render(_InlineList || (_InlineList = /*#__PURE__*/React.createElement(InlineList, null, /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 1"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 2"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 3"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 4"), null, false)));
    const listItems = screen.getAllByRole('listitem');
    expect(listItems.length).toEqual(4);
  });
  it('should render a delimiter when delimiter="pipe"', async () => {
    const _render = render(_InlineList2 || (_InlineList2 = /*#__PURE__*/React.createElement(InlineList, {
        delimiter: "pipe"
      }, /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 1"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 2"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 3"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 4")))),
      container = _render.container;
    const delimiters = container.querySelectorAll('span[aria-hidden="true"]');
    expect(delimiters.length).toEqual(4);
    delimiters.forEach(delimiter => {
      expect(delimiter.getAttribute('class')).toContain('inlineListItem__delimiter');
    });
  });
  it('should warn when itemSpacing is set when delimiter is set to anything other than none', async () => {
    render(_InlineList3 || (_InlineList3 = /*#__PURE__*/React.createElement(InlineList, {
      delimiter: "pipe",
      itemSpacing: "large"
    }, /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 1"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 2"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 3"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 4"))));
    const warning = `Warning: [InlineList] \`itemSpacing\` has no effect inside Lists with the \`delimiter\` prop set to anything other than \`none\`.`;
    expect(consoleErrorMock.mock.calls[0][0]).toBe(warning);
  });
  it('should render an ordered list', async () => {
    render(_InlineList4 || (_InlineList4 = /*#__PURE__*/React.createElement(InlineList, {
      as: "ol"
    }, /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 1"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 2"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 3"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 4"))));
    const list = screen.getByRole('list');
    expect(list.tagName).toBe('OL');
  });
  it('should meet a11y standards', async () => {
    const _render2 = render(_InlineList5 || (_InlineList5 = /*#__PURE__*/React.createElement(InlineList, null, /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 1"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 2"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 3"), /*#__PURE__*/React.createElement(InlineList.Item, null, "List item 4")))),
      container = _render2.container;
    const axeCheck = await runAxeCheck(container);
    expect(axeCheck).toBe(true);
  });
});

==> ui-list-10.19.1.tgz: package/es/InlineList/__new-tests__/InlineList.test.js <==
var _InlineList, _InlineList2, _InlineList3, _InlineList4, _InlineList5;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import '@testing-library/jest-dom';
import { render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import { InlineList } from '../index';
import { runAxeCheck } from '@instructure/ui-axe-check';
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
describe('<InlineList />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render list items and filter out null/falsy children', async () => {
    render(_InlineList || (_InlineList = _jsxs(InlineList, {
      children: [_jsx(InlineList.Item, {
        children: "List item 1"
      }), _jsx(InlineList.Item, {
        children: "List item 2"
      }), _jsx(InlineList.Item, {
        children: "List item 3"
      }), _jsx(InlineList.Item, {
        children: "List item 4"
      }), null, false]
    })));
    const listItems = screen.getAllByRole('listitem');
    expect(listItems.length).toEqual(4);
  });
  it('should render a delimiter when delimiter="pipe"', async () => {
    const _render = render(_InlineList2 || (_InlineList2 = _jsxs(InlineList, {
        delimiter: "pipe",
        children: [_jsx(InlineList.Item, {
          children: "List item 1"
        }), _jsx(InlineList.Item, {
          children: "List item 2"
        }), _jsx(InlineList.Item, {
          children: "List item 3"
        }), _jsx(InlineList.Item, {
          children: "List item 4"
        })]
      }))),
      container = _render.container;
    const delimiters = container.querySelectorAll('span[aria-hidden="true"]');
    expect(delimiters.length).toEqual(4);
    delimiters.forEach(delimiter => {
      expect(delimiter.getAttribute('class')).toContain('inlineListItem__delimiter');
    });
  });
  it('should warn when itemSpacing is set when delimiter is set to anything other than none', async () => {
    render(_InlineList3 || (_InlineList3 = _jsxs(InlineList, {
      delimiter: "pipe",
      itemSpacing: "large",
      children: [_jsx(InlineList.Item, {
        children: "List item 1"
      }), _jsx(InlineList.Item, {
        children: "List item 2"
      }), _jsx(InlineList.Item, {
        children: "List item 3"
      }), _jsx(InlineList.Item, {
        children: "List item 4"
      })]
    })));
    const warning = `Warning: [InlineList] \`itemSpacing\` has no effect inside Lists with the \`delimiter\` prop set to anything other than \`none\`.`;
    expect(consoleErrorMock.mock.calls[0][0]).toBe(warning);
  });
  it('should render an ordered list', async () => {
    render(_InlineList4 || (_InlineList4 = _jsxs(InlineList, {
      as: "ol",
      children: [_jsx(InlineList.Item, {
        children: "List item 1"
      }), _jsx(InlineList.Item, {
        children: "List item 2"
      }), _jsx(InlineList.Item, {
        children: "List item 3"
      }), _jsx(InlineList.Item, {
        children: "List item 4"
      })]
    })));
    const list = screen.getByRole('list');
    expect(list.tagName).toBe('OL');
  });
  it('should meet a11y standards', async () => {
    const _render2 = render(_InlineList5 || (_InlineList5 = _jsxs(InlineList, {
        children: [_jsx(InlineList.Item, {
          children: "List item 1"
        }), _jsx(InlineList.Item, {
          children: "List item 2"
        }), _jsx(InlineList.Item, {
          children: "List item 3"
        }), _jsx(InlineList.Item, {
          children: "List item 4"
        })]
      }))),
      container = _render2.container;
    const axeCheck = await runAxeCheck(container);
    expect(axeCheck).toBe(true);
  });
});
